[![Documentation Status](https://readthedocs.org/projects/hippomaps/badge/?version=latest)](https://hippomaps.readthedocs.io/en/latest/?badge=latest)
![Version](https://img.shields.io/github/v/tag/jordandekraker/hippomaps?label=version)
<img align="right" width="200" src="https://github.com/MICA-MNI/hippomaps/blob/master/docs/source/HMlogo1.png">


HippoMaps🍤
=====================================
This is a toolbox and repository for open source mapping and contextualization of hippocampal data, paralleling surface-based mapping of the neocortex. This is partnered with a repository of mapped data at [OSF](https://osf.io/92p34/). 


Documentation📝
-------------------------------------

See [here](https://hippomaps.readthedocs.io/en/latest/) for installation instructions, details on all tools provided, and tutorial walkthroughs. 

Overview👁️
-------------------------------------

HippoMaps provides tools for mapping data the folded and unfolded hippocampus are designed to work seamlessly with outputs generated by [HippUnfold](https://github.com/khanlab/hippunfold/). 

<img width="600" src="https://github.com/MICA-MNI/hippomaps/blob/master/docs/source/HMfig1.png">

In the [tutorials](https://github.com/jordandekraker/hippomaps/tree/master/tutorials/), we provide examples for mapping:

- laminar ex-vivo histology at the microscale
- structural MRI at 3T and 7T
- resting state fMRI properties and connectivity 
- spatially scattered intracranial EEG (iEEG) recodings
- task-fMRI data mapping with [nilearn](https://nilearn.github.io/stable/)
- comparison between maps and dimensionality reduction

These tutorials provide clear examples of how the tools here can be used, but for shorter examples and usage notes, see also [demos](https://github.com/jordandekraker/hippomaps/tree/master/hippomaps/demos/).

Other relevant repositories🗂️
-------------------------------------

[hippunfold](https://github.com/khanlab/hippunfold/)

[hippunfold_toolbox](https://github.com/jordandekraker/hippunfold_toolbox/)

[Hippo_Spin_Testing](https://github.com/Bradley-Karat/Hippo_Spin_Testing/)

[BrainSpace](https://github.com/MICA-MNI/BrainSpace/)

[micapipe](https://github.com/MICA-MNI/micapipe/)

[Eigenstrapping](https://github.com/SNG-Newy/eigenstrapping)

Citing HippoMaps📝
-------------------------------------

DeKraker, J., Cabalo, D. G., Royer, J., Khan, A. R., Karat, B., Benkarim, O., ... & Bernhardt, B. C. (2024). HippoMaps: Multiscale cartography of the human hippocampal formation. bioRxiv, 2024-02. [link](https://www.biorxiv.org/content/10.1101/2024.02.23.581734v1)

For use of additional data in the [OSF repo](https://osf.io/92p34/), please cite the original authors of each map.

Join the Open Source Adventure!🚀
-------------------------------------
No contribution is too small! Whether you're fixing a bug, adding a feature, or improving documentation, every contribution counts!  
